#
# spec file for package libvterm
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
%{?!make_build:%define make_build %{__make} %{_make_output_sync} %{?_smp_mflags} %{_make_verbose}}
%{?!_make_output_sync:%define _make_output_sync %(! %{__make} --version -O >/dev/null 2>&1 || echo -O)}
%{?!_make_verbose:%define _make_verbose V=1 VERBOSE=1}

Name:           libvterm
Version:        0.1.3
Release:        lp152.1.2
Summary:        An abstract library implementation of a VT220/xterm/ECMA-48 terminal emulator
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://launchpad.net/libvterm
Source:         https://launchpad.net/libvterm/trunk/v0.1/+download/libvterm-%{version}.tar.gz
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
An abstract C99 library which implements a VT220 or xterm-like terminal
emulator.

%package -n %{name}%{sover}
Summary:        Shared library package of libvterm
Group:          System/Libraries

%description -n %{name}%{sover}
An abstract C99 library which implements a VT220 or xterm-like
terminal emulator. It does not use any particular graphics toolkit or
output system. Instead, it invokes callback function pointers that
its embedding program should provide it to draw on its behalf.

%package devel
Summary:        Development files of libvterm
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
This package contains the development files of libvterm.

%package tools
Summary:        Tools for libvterm
Group:          System/Console

%description tools
This package contains tools for libvterm.

%prep
%setup -q

%build
%make_build PREFIX=%{_prefix} \
     LIBDIR=%{_libdir} \
     CFLAGS="%{optflags}"

%install
make PREFIX=%{_prefix} \
     LIBDIR=%{_libdir} \
     DESTDIR=%{buildroot} \
     install

# Remove libtool files.
find %{buildroot} -type f -name "*.la" -delete -print

# Remove static library file.
rm -vf %{buildroot}%{_libdir}/%{name}.a

%post   -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license LICENSE
%{_libdir}/%{name}.so.*

%files devel
%{_includedir}/vterm*.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/vterm.pc

%files tools
%{_bindir}/unterm
%{_bindir}/vterm-ctrl
%{_bindir}/vterm-dump

%changelog
* Mon Mar 30 2020 Matej Cepl <mcepl@suse.com>
- All my previous builds were just figments of my imagination,
  and neovim upstream claims one has to use 0.1.3 only. So,
  downgrading.
* Mon Mar 30 2020 Matej Cepl <mcepl@suse.com>
- Update to 0.1.3+bzr767:
  - Remove debugging print on DECRQSS
  - Regenerate fullwidth.inc for latest Unicode
  - A much more efficient find-wide-chars.pl
  - Accept OSC ... ST without an intermediate semicolon after the
    command number
  - Fix printf argument types (gh#vim/vim#5456)
* Sat Jan 11 2020 Matej Cepl <mcepl@suse.com> 
- Update to 0.1.3+bzr762:
  - Merge bugfixes up to v0.1.3
  - Partial bugfix for uncleared area after resize (thanks Jörg
    Richter)
  - Recognise SGR 8 for conceal (thanks Jörg Richter)
  - Define a new dedicated 'state fallbacks' struct rather than
    abusing the parser callbacks one
  - New string-handling API that streams in possibly-multiple
    fragments
  - Remember to length-check accesses at cell->chars[] because it
    is not necessarily zero-terminated (LP 1846869)
  - fix memory leak of vt->tmpbuffer (LP 1843449)
* Wed Sep 18 2019 Martin Liška <mliska@suse.cz>
- Make build verbose and respect $optflags.
* Wed Sep 11 2019 Matej Cepl <mcepl@suse.com>
- Update to 0~bzr755:
  - 755 t/run-test.pl option to abort on first fail
  - 754 Accept convenience formatting in ?screen_chars assertions; makes unit
    tests more readable
  - 753 Include test script line number in t/run-test.pl output
  - 752 Add a short unit test that resize on altscreen at least doesn't crash
  - 751 Only enable altscreen during unit tests that need it
  - 750 Better handling of resize to try to avoid the final memmove(), and not
    drag scrollback in unnecessarily
  - 749 Can't lazy-allocate state->lineinfos[BUFIDX_ALTSCREEN] because that
    allocs during byte run
  - 748 Initial hack at tracking 'continuation' marks per line in lineinfo
  - 747 Allow run-test.pl to cope with empty assertion results
  - 746 Be sure to clear DWL/DHL status for blank lines caused by scroll
  - 745 Pass 'state fields' as a struct into resize callback in case of other
    things it needs to edit
  - 744 Remember to store a state->lineinfo array for both buffers
  - 743 Do all the initialising of VTermState in vterm_state_new()
  - 742 Rename realloc_buffer() to just alloc_buffer() since it doesn't need to
    realloc now
  - 741 Rewrite of resize handling logic to hopefully cope much better with
    reflow
  - 739 Recognise an __END__ marker in a unit test file
  - 738 Add a version check macro
  - 737 Bump version to 0.1
  - 736 Recognise SGR 4:3 for curly underline
  - 735 Recognise subparameters in SGR 4:x to set off/single/double
  - 734 Define some enum{} constants for pen.underline field values
  - 733 Run unit tests on outfunc instead of buffering logic; truncation test
    is no longer valid now
  - 732 Optional vterm_output_set_callback() to set an output func; will
    eventually replace buffer logic
  - 731 Implement Query SGR by building a tmpbuffer then making a single
    vterm_push_output call
  - 730 More efficient one-line implementation of DCS and ST rendering parts of
    _output_sprintf_dcs
  - 729 Rewrite vterm_push_output_* functions to use a new tmpbuffer on main VT
    object, push all output via _output_bytes()
  - 728 The F1 to F4 keys should send SS3 rather than CSI when unmodified
  - 727 Expose cell colour index as API value (LP1805035)
  - 726 Document REP sequence
  - 725 Rename/number some more state-related tests
  - 724 Renumber the 4x test series up to 6x to make plenty more space for
    state tests
  - 723 Implement REP CSI (LP1805050)
  - 722 Add --executable/-e flag to run-test.pl (LP1805034)
  - 721 Ship src/*.inc files to destdir (thanks jamessan)
  - 720 Add unit test for fullwidth emoji char
  - 719 Initial attempt at better handling of double-width unicode characters
  - 718 Fix implementation of query on bracketed paste mode (thanks jamessan)
  - 717 Need to use 1U << 31 to keep C++ compilers happy (thanks jamessan)
  - 716 Make sure to use CSI_* macros rather than hardcoding (1<<31) in
    unterm.c (thanks jamessan)
  - 715 Add DECSM 1004 to documentation
  - 714 Move 'reportfocus' to keep numerical ordering in vterm-ctrl.c
  - 713 Merge lp:~jamessan/libvterm/focus-events
  - 712 Move strbuffer into the .parser sub-struct
  - 711 Internal rearrangement of string state handling in parser, to better
    fit upcoming new API
  - 710 Now that parser 'text' callback should always make progress, no need to
    use the strbuffer for it
  - 709 Bugfix to account for UTF-8 decoder still consuming initial bytes of
    a partial sequence
  - 708 Improved handling of ESC parsing so it doesn't use the temporary
    strbuffer
  - 707 Found another document about escape sequences
  - 706 An improved CSI parser that does not use the temporary strbuffer but
    instead works entirely incrementally
  - 705 Move parser-related state into its own sub-structure
  - 704 Fix -Wpedant warnings from t/harness.c
  - 703 Compile with -Wpedantic
  - 702 Minor other syntax pedant fixes to bin/*.c files
  - 701 Make all bitfields 'unsigned int'
  - 700 Use an ifdef instead of commented code in parser.c's debugging
  - 699 Ensure that all enums in header files lack a trailing comma, because
    some older C++ compilers won't like that
  - 698 Remeber to 'return 0' at the end of main() in the binaries
  - 697 Avoid the \e escape in string literals in bin/*.c; replace with \x1b
- Removed _service file, bzr on Tumbleweed is too broken to be
  used automatically, rather use upstream tarballs.
* Mon May 29 2017 ronisbr@gmail.com
- Run spec-cleaner.
- Fix `libvterm.changes` indentation.
* Sat May 27 2017 bwiedemann@suse.com
- Version bump to 0~bzr696.
  Changelog:
  * Add S8C1T control support to vterm-ctrl
  * Implement querying of cursor shape in vterm-ctrl
  * Remember to document ST in doc/seqs.txt
  * Adjust linebreaking of 'break' statements to avoid gcc
    warnings of misleading indentation
  * Implement DECRQSS on SGR when set to RGB8 palette colours
  * Reset the pen between independent tests of DECRQSS on SGR
  * Bugfix for disabling mouse mode
  * Ensure stdin's ICANON mode is restored even if vterm-ctrl
    exits on error
  * Initialise mouse state at VTermState creation rather than as
    a side-effect of DECSM 100{0,2,3} - fixes LP1640917
  * Pull VTermScreenCell.attrs out to its own named type
  * Merge lp:~jamessan/libvterm/reproducibility (#307773,
    boo#1041090)
* Thu Aug 25 2016 ronisbr@gmail.com
- Version bump to 0~bzr684.
  Changelog:
  * Avoid "\e" because some C compilers don't like it
  * Don't use wchar_t in unicode.c as it might not be big enough
  * Remember to pass unicode codepoints in uint32_t rather than
    int
* Sun Apr 10 2016 ronisbr@gmail.com
- Version bump to 0~bzr681.
  Changelog:
  * Bugfix(?) for SunOS (thanks DominoTree -
    https://github.com/neovim/libvterm/pull/1/files)
  * (Alt-)Ctrl-Space should encode as (\e)\0
* Sat Dec  5 2015 jengelh@inai.de
- Move description from main part to shlib part, since this will be
  the one that always gets installed.
* Sat Dec  5 2015 ronisbr@gmail.com
- Remove unnecessary dependency from libvterm-tool.
* Sat Dec  5 2015 ronisbr@gmail.com
- Remove libtool files.
- Fix groups for libvterm, libvterm0, and libvterm-tools.
- Change package compression from .tar.gz to .tar.xz.
- Change %%{soname} to %%{sover}.
* Sat Dec  5 2015 ronisbr@gmail.com
- Change package name to libvterm.
* Wed Dec  2 2015 ronisbr@gmail.com
- Initial version based on home:gmc137:neovim/libvterm.
- Version bump to 0~bzr679.
- Change package version scheme to match openSUSE's guidelines.
- Clean spec file.
- Drop obsolete patch libvterm.optflags.patch.
